<?php

/**
 * Implements hook_field_read_fields_alter().
 *
 * You've added this alter to field_read_fields(), to make this module work.
 *
 * All field info will go through this hook and be cached, so you can do some
 * magic in here, but don't push it. There's also hook_field_read_field(), but
 * that's not an alter and it runs too early.
 */
function hook_field_read_fields_alter(&$fields) {
  // Change the field settings/config to all modules using field_info_field()
  // see those changes.
  foreach ($fields as $i => $field) {
    $fields[$i]['translatable'] = 1;
  }

  // Give every field another column. This only makes Field think the column
  // exists! It doesn't actually create it in the db!
  foreach ($fields as $i => $field) {
    // If the column is called 'secondary_language' here, it should be
    // called 'FIELD_NAME_secondary_language' in the db.
    $fields[$i]['columns']['secondary_language'] = array(
      'type' => 'text',
    );
  }

  // This is apparently important to Views...
  reset($fields);
}

/**
 * Implements hook_field_widget_form_alter().
 *
 * This is an example of how easy it is to make that new column work for
 * you. In this case we're exposing custom column 'secondary_language' in
 * field 'field_images'. This is all you need. Storage and loading will
 * be handled by Field.
 */
function hook_field_widget_form_alter(&$element, &$form_state, $context) {
  if ($element['#field_name'] == 'field_images') {
    $field = field_info_field($element['#field_name']);

    if (isset($field['columns']['secondary_language'])) {
      foreach (element_children($element) as $delta) {
        if (!empty($element[$delta]['#default_value']['fid'])) {
          $item = $element[$delta]['#default_value'];

          $element[$delta]['secondary_language'] = array(
            '#type' => 'select',
            '#title' => t('Secondary language'),
            '#options' => array('nl' => 'Dutch', 'en' => 'English', 'fr' => 'French', 'de' => 'German'),
            '#default_value' => $item['secondary_language'] ?: '',
            '#empty_option' => '--',
            '#empty_value' => '',
          );
        }
      }
    }
  }
}
